==> haskell-cookie-0.4.5-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cookie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cookie
version:              0.4.5
visibility:           public
id:                   cookie-0.4.5-B1GcTZOCb6yBzxFcoqFiFA
key:                  cookie-0.4.5-B1GcTZOCb6yBzxFcoqFiFA
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://github.com/snoyberg/cookie
synopsis:             HTTP cookie parsing and rendering
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/cookie>.

category:             Web, Yesod
abi:                  b6758bd2f2734fe37c9d8eb8ebb986e2
exposed:              True
exposed-modules:      Web.Cookie
import-dirs:          /usr/lib/ghc-9.0.2/site-local/cookie-0.4.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cookie-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/cookie-0.4.5
hs-libraries:         HScookie-0.4.5-B1GcTZOCb6yBzxFcoqFiFA
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO deepseq-1.4.5.0
    text-1.2.5.0 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-cookie/html/cookie.haddock
haddock-html:         /usr/share/doc/haskell-cookie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cookie-0.4.6-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cookie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cookie
version:              0.4.6
visibility:           public
id:                   cookie-0.4.6-AQamA5QJzxUGLdn7cmcakq
key:                  cookie-0.4.6-AQamA5QJzxUGLdn7cmcakq
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://github.com/snoyberg/cookie
synopsis:             HTTP cookie parsing and rendering
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/cookie>.

category:             Web, Yesod
abi:                  82d814a50b752ebf678605668a37766d
exposed:              True
exposed-modules:      Web.Cookie
import-dirs:          /usr/lib/ghc-9.0.2/site-local/cookie-0.4.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cookie-0.4.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cookie
hs-libraries:         HScookie-0.4.6-AQamA5QJzxUGLdn7cmcakq
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO deepseq-1.4.5.0
    text-1.2.5.0 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-cookie/html/cookie.haddock
haddock-html:         /usr/share/doc/haskell-cookie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
